@@ -97,7 +97,12 @@ def close_conn(request_id):
         return make_rsp('sock not in socket_map')
     else:
         # 这个是真正破坏掉链接，close则不会
-        sock.shutdown(socket.SHUT_RDWR)
+        try:
+            sock.shutdown(socket.SHUT_RDWR)
+        except:
+            pass #some platforms may raise ENOTCONN here
+        # 还要再调用一次close，参看 SocketServer
+        sock.close()
         return make_rsp('sock succ closed')
 
 
