@@ -17,4 +17,4 @@ RET_SYSTEM = -9999
 ERROR_INTERNAL = u'internal error'
 
 # 每次loop的超时
-LOOP_TIMEOUT = 30.0
\ No newline at end of file
+POLL_TIMEOUT = 10.0
\ No newline at end of file
