@@ -147,7 +147,7 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
             poll_fun = asyncore.poll
 
         while self._map:
-            poll_fun(constants.LOOP_TIMEOUT, self._map)
+            poll_fun(constants.POLL_TIMEOUT, self._map)
             # after_poll_func_list
             for func in self.after_poll_func_list:
                 try:
@@ -242,7 +242,7 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
             poll_fun = asyncore.poll
 
         while self._map:
-            poll_fun(constants.LOOP_TIMEOUT, self._map)
+            poll_fun(constants.POLL_TIMEOUT, self._map)
             # after_poll_func_list
             for func in self.after_poll_func_list:
                 try:
